# FILE: PlotRatio.gp
# COPYRIGHT (c): Symmetric Research, 2011-2016
#
# This GnuPlot file plots both data from two USBxCH channels and the ratio
# of those channels.  It assumes one channel contains data from a 
# potentiometer style sensor and the other contains data from the excitation
# source controlling the top of the sensor range.
#
# To run, call PlotRatio.bat or go down to the directory with Ratio.fw4,
# start GnuPlot and use ...  load '..\PlotRatio.gp'
#
#



# REMOVE ANY PREVIOUS DEFAULT SETTINGS
#
#

reset




# DEFINE SOME HANDY CONSTANTS RELATED TO THE DATA FILE
#
#

DataFile = "Ratio.fw4"



# Set the sample number and data columns.
# When changing the sensor and source columns, remember to change the 
# explicit $2/$3 values in the plot statement below.

ColSample = 1          # sample number  is in column 1
ColSensor = 2          # sensor data    is in column 2
ColSource = 3          # source data    is in column 3




# DEFINE LABEL FOR AXES, PLOT AND KEY AND CONTROL RANGE OF AXES
#
# Offset on ylabel moves it 5 characters to the left (-5 in x direction,
# and 0 in the y direction) so it doesn't run into the count values.
#
#

set xlabel "Sample Number"               font "Helvetica Bold,14"
set ylabel "Volts or Ratio"              font "Helvetica Bold,14"
set title  "USBxCH Ratiometric Example"  font "Helvetica Bold,18"

KeyTitleSensor = "Sensor data"
KeyTitleSource = "Source data"
KeyTitleRatio  = "Sensor/Source Ratio"

set xtics nomirror                      font "Helvetica Bold,14"
set ytics nomirror                      font "Helvetica Bold,14"




# SET THE DATA PLOTTING STYLE
#
# The first set style says plot data with points connected by lines.
# The next set styles defines linestyle 1, 2, and 3 that can be referenced 
# later by the plot command.  The first style has red lines with box points,
# the second has blue lines with triangle points, and the third style has
# black lines with circle points.
#

set style data linespoint
set style line 1 linetype  1 linewidth 2 pointtype 5 pointsize 1
set style line 2 linetype  3 linewidth 2 pointtype 9 pointsize 1
set style line 3 linetype -1 linewidth 2 pointtype 7 pointsize 1



# NOW DO THE PLOTS
#
#


set yrange [0:4]

plot DataFile using ColSample:ColSource linestyle 1 title KeyTitleSource, \
     DataFile using ColSample:ColSensor linestyle 2 title KeyTitleSensor, \
     DataFile using ColSample:($2/$3)   linestyle 3 title KeyTitleRatio


pause -1 "Press enter to exit GnuPlot"


# CLEAN UP SETTINGS
#
#

reset
