@echo off

rem FILE: Ratio.bat  ( Example Ratiometric Technique )
rem COPYRIGHT: (c), Symmetric Research, 2016
rem
rem This example sets up a pipeline to acquire data from a USBxCH board
rem connected to a potentiometer type sensor output and an excitation source.
rem The pipeline is:  Blast -> Pak2Bin -> Interp -> Bin2Asc -> DvmDisplay
rem 
rem Use the associated PlotRatio.bat file to plot the results and see the
rem benefits of ratiometric techniques.
rem


rem Save path to the current example directory.

set EXAMPLEDIR=%CD%


rem Keep all title and path changes local ( ie restore on exit )

setlocal

title SR RATIO.BAT - ( Acquire Ratiometric Potentiometer Data)
path C:\SR\USBXCH\Exe;%PATH%



rem Announce the program start:

echo RATIO.BAT: Starting ...
echo.




rem Create a YMDHMS data directory:
rem
rem YMDHMS = ( year, month, day, hour, minute, second).
rem
rem The SR YmdHms.exe utility creates a blank YMDHMS directory for storing data
rem from the current acquisition run.  An actual directory name will be 
rem something like "2014-05-29-at-15-47-46" reflecting the current date and 
rem time.
rem
rem YmdHms.exe also writes the batch file YmdHmsSetEnv.bat for setting an
rem environment variable with the specific YMDHMS that can be referred to in 
rem the rest of this batch file.
rem
rem All processing utilities are run in the YMDHMS directory so any output
rem files are saved there.
rem
rem

echo.
echo RATIO.BAT: Creating the YMDHMS data directory for this run:

YmdHms  > nul
call YmdHmsSetEnv.bat

echo.
echo    success ... created: %SR_YMDHMS%
cd %SR_YMDHMS%




rem Check for USBxCH driver and board presence.

echo.
echo RATIO.BAT: Checking for USBxCH presence ( SrUsbXch0 ):
echo.

Presence.exe SrUsbXch0

if ERRORLEVEL 1  goto :Return




rem Set an environment variable with the INI file name.
rem
rem Take the name from the batch command line or use the default.  This
rem one file is shared among all of the pipeline utilities comprising 
rem Ratio.bat and has [sections] for each utility.
rem
rem NOTE: Referring to a batch argument with percent tilda like %~1 
rem       instead of %1 strips off any quotes.  The quotes can be added 
rem       later where they are needed.
rem       
rem       

set INIFILE=%~1
if "%INIFILE%" == "" (
        set INIFILE=%EXAMPLEDIR%\Ratio.ini
)



rem Check the INI syntax:
rem
rem Before actually executing it is best to check the INI syntax.  If there is
rem a syntax error, this batch file terminates.  Fix the error and try again.
rem 
rem Note:
rem
rem These syntax checks are done without the /to clause on the utilities.  
rem Because of that the "nextprog" field on the INI reports will be reported 
rem as NULL.  See below for the /to clause on each when the utilities are 
rem actually run.
rem 
rem 

echo.
echo.
echo.
echo RATIO.BAT: Checking INI syntax:
echo.

Blast /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Pak2Bin /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Interp /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Bin2Asc /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

DvmDisplay /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

goto :SyntaxGood


:SyntaxError
echo. 
echo RATIO.BAT: ERROR, failed INI syntax check, quitting ...
echo. 
goto :Return

:SyntaxGood
echo.
echo RATIO.BAT: SUCCESS, INI syntax check passed ...
echo.




rem Start the pipeline chain in the background.
rem
rem NOTES:
rem
rem * Sampling rates, etc ... are all set in the single INI file
rem * "Start /b" is the Windows way of starting a process in the background
rem
rem

echo.
echo.
echo RATIO.BAT: Starting the pipeline in the background ...

start /b          Blast.exe  "%INIFILE%"  /to Pak2Bin
start /b        Pak2Bin.exe  "%INIFILE%"  /to Interp
start /b         Interp.exe  "%INIFILE%"  /to Bin2Asc
start /b        Bin2Asc.exe  "%INIFILE%"  /to DvmDisplay
start /b     DvmDisplay.exe  "%INIFILE%"  /to NULL

echo RATIO.BAT: background pipeline started ... see *.rpt files for info
echo.



rem Return, telling the user what will happen.
rem
rem

:Return

echo.
echo.
echo RATIO.BAT: Return NOTE
echo.
echo If Ratio.bat was started by double clicking from Windows File Explorer,
echo this window will go away after "press any key to continue" ...
echo.
echo If Ratio.bat was started from a command prompt, it will return to the
echo command prompt.  Run tasklist etc to see processes running ...
echo.
pause
echo.

