@echo off

rem FILE: DvmSolar.bat  ( Example GnuPlot )
rem COPYRIGHT: (c), Symmetric Research, 2014-2016
rem
rem Batch file for generating solar cell data for GnuPlot example.
rem
rem



rem Save path to the current example directory.

set EXAMPLEDIR=%CD%


rem Keep all title and path changes local ( ie restore on exit )

setlocal

title SR DVMSOLAR.BAT - ( GnuPlot Solar Cell Data )
path C:\SR\USBXCH\Exe;%PATH%



rem Announce the program start:

echo DVMSOLAR.BAT: Starting ...
echo.




rem Check for USBxCH driver and board presence.

echo.
echo DVMSOLAR.BAT: Checking for USBxCH presence ( SrUsbXch0 ):
echo.

Presence.exe SrUsbXch0

if ERRORLEVEL 1  goto :Return




rem Set an environment variable with the INI file name.
rem

set INIFILE=%EXAMPLEDIR%\DvmSolar.ini



rem Check the INI syntax:
rem
rem Before actually executing it is best to check the INI syntax.  If there is
rem a syntax error, this batch file terminates.  Fix the error and try again.
rem 
rem Note:
rem
rem These syntax checks are done without the /to clause on the utilities.  
rem Because of that the "nextprog" field on the INI reports will be reported 
rem as NULL.  See below for the /to clause on each when the utilities are 
rem actually run.
rem 
rem 

echo.
echo.
echo.
echo DVMSOLAR.BAT: Checking INI syntax:
echo.

Blast /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Pak2Bin /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Interp /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

BinFwrite /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Bin2Asc /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

DvmDisplay /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

goto :SyntaxGood


:SyntaxError
echo. 
echo DVMSOLAR.BAT: ERROR, failed INI syntax check, quitting ...
echo. 
goto :Return

:SyntaxGood
echo.
echo DVMSOLAR.BAT: SUCCESS, INI syntax check passed ...
echo.




rem Start the pipeline chain in the background.
rem
rem NOTES:
rem
rem * Sampling rates, etc ... are all set in the single INI file
rem * "Start /b" is the Windows way of starting a process in the background
rem
rem

echo.
echo.
echo DVMSOLAR.BAT: Starting the pipeline in the background ...

start /b        Blast.exe  "%INIFILE%"  /to Pak2Bin
start /b      Pak2Bin.exe  "%INIFILE%"  /to Interp
start /b       Interp.exe  "%INIFILE%"  /to BinFwrite
start /b    BinFwrite.exe  "%INIFILE%"  /to Bin2Asc
start /b      Bin2Asc.exe  "%INIFILE%"  /to DvmDisplay
start /b   DvmDisplay.exe  "%INIFILE%"  /to NULL

echo DVMSOLAR.BAT: background pipeline started ... see *.rpt files for info
echo.



rem Return, telling the user what will happen.
rem
rem

:Return

echo.
echo.
echo DVMSOLAR.BAT: Return NOTE
echo.
echo If Dvm.bat was started by double clicking from Windows File Explorer,
echo this window will go away after "press any key to continue" ...
echo.
echo If Dvm.bat was started from a command prompt, it will return to the
echo command prompt.  Run tasklist etc to see processes running ...
echo.
pause
echo.

