# FILE: Plot2.gp
# COPYRIGHT (c): Symmetric Research, 2010-2016
#
# This GnuPlot file plots time versus channel 0 light level data from 
# the USB8CH file DvmSolar.fw8.  See Plot1.gp for a brief description of
# this file.
#
# The following command plots data from the time (19) and channel 0 (2) 
# columns against each other.  It also applies an offset to all the time 
# values in column 19.
#
# The "using" option says to plot the data from columns 19 and 2.  Using the
# form ($19) instead of just 19 allows computations to be done on the data
# in column 19 before it is plotted.  In this case, the computation is to
# subtract the time value of the first point since that normalizes the time
# value so it runs from 0 at start of the acquisition instead of at Jan 1, 1970.
# For fw4 files, time is is column 15.
#
# If you want to use the time in year/month/day format from column 20+21 
# instead of the time as seconds from 1970 from column 19, you'll want to add 
# the following GnuPlot commands:
#
#    set timefmt "%Y/%m/%d %H:%M:%S"
#    set format x "%M:%S"
#    set xdata time
#
# The first of these commands tells GnuPlot what format the time is in so it 
# knows how to interpret the values it reads.  The second describes how the time
# should be printed on the x axis and the third tells GnuPlot to use timefmt 
# when reading values for the x axis.
#
# However, please note that the fractional seconds in the data file are ignored
# since there are no available GnuPlot time formats for reading them in.  If
# the fractional seconds are important when plotting your data, you should use
# the time in seconds since 1970 column instead.  
#
# Sometimes there is so much data in a file that it is not necessary to plot
# all the points.  Plot3.gp does this.
#

StartTime = 1464377866.000

plot "DvmSolar.fw8" using ($19-StartTime):2
