@echo off

rem FILE: "SR WatchDog.bat"
rem COPYRIGHT: (c), Symmetric Research, 2011-2018
rem
rem Check whether a particular program is running.  If not, restart.  Specify
rem the program with the environment variables below.
rem
rem Use the companion batch file "SR WatchDog Schedule.bat" to schedule this
rem watchdog batch file as a periodic Windows process.
rem
rem

rem Start by saving the path to this example directory and changing to it.

set PROGRAMPATH=C:\SR\USBXCH\Examples\006 UsbXch General - WatchDog Task Monitoring

cd "%PROGRAMPATH%"


rem Edit the SrTask files in this directory so they do the job you want
rem
rem CLEANUPNAME is the name of the script to cleanup after failure
rem RESTARTNAME is the name of the script to start a new run
rem SEARCHNAME  is the name to look for in the process list and should
rem               be one of the processes started by RESTARTNAME 
rem

set CLEANUPNAME=KillSrTask.bat
set RESTARTNAME=SrTask.bat
set SEARCHNAME=Blast.exe

set CLEANUP_CMD=start "WatchDog cleanup" /Wait cmd /c "%PROGRAMPATH%\%CLEANUPNAME%"
set RESTART_CMD=start "WatchDog restart" /MIN cmd /c "%PROGRAMPATH%\%RESTARTNAME%"
set REPORTFILE="%PROGRAMPATH%\WatchDog.rpt"



rem CHECK WHETHER PROGRAMNAME IS RUNNING ON THE TASKLIST:
rem
rem Scan the tasklist with find to see if the specified program is listed.  
rem If not, then restart.
rem
rem NOTE:
rem
rem   > nul is used to ignore any find stdout output.  We only care about the
rem   success or failure returned by the find ERRORLEVEL.
rem
rem

tasklist | find "%SEARCHNAME%" > nul

if %ERRORLEVEL% EQU 0   (

        echo [%DATE% %TIME%] %SEARCHNAME% is running OK
        echo [%DATE% %TIME%] %SEARCHNAME% is running OK       >> %REPORTFILE%

) else (

        echo [%DATE% %TIME%] Restarting %RESTARTNAME% ...
        echo       %CLEANUP_CMD%                               
        echo       %RESTART_CMD%
        echo.                                                  >> %REPORTFILE%
        echo [%DATE% %TIME%] Restarting %RESTARTNAME% with ... >> %REPORTFILE%
        echo       %CLEANUP_CMD%                               >> %REPORTFILE%
        echo       %RESTART_CMD%                               >> %REPORTFILE%
        echo.                                                  >> %REPORTFILE%
        %CLEANUP_CMD%
        %RESTART_CMD%
)

@echo on
