@echo off

rem FILE: SrTask.bat  ( WatchDog Example )
rem COPYRIGHT: (c), Symmetric Research, 2013-2016
rem
rem This is a demo program.  It shows how to set up a pipeline to acquire data
rem a USB4CH board and save it to a file.
rem
rem "The program" is actually this batch file.  Three pipeline utilities are
rem used: ( Blast , Pak2Bin , Bin2Asc ).  Data moves from one utility to
rem the next via intermediate named pipes.
rem
rem
rem


rem Keep all title and path changes local ( ie restore on exit )

setlocal

title SR SRTASK.BAT - ( Blast to File Task )
path C:\SR\USBXCH\Exe;%PATH%



rem Announce the program start:

echo SRTASK.BAT: Starting ...
echo.



rem Create a YMDHMS data directory:
rem
rem YMDHMS = ( year, month, day, hour, minute, second).
rem

echo.
echo SRTASK.BAT: Creating the YMDHMS data directory for this run:

YmdHms  > nul
call YmdHmsSetEnv.bat

echo.
echo    success ... created: %SR_YMDHMS%
cd %SR_YMDHMS%




rem Check for USBxCH driver and board presence.

echo.
echo SRTASK.BAT: Checking for USBxCH presence ( SrUsbXch0 ):
echo.

Presence.exe SrUsbXch0

if ERRORLEVEL 1 goto :Return



rem Set an environment variable with the INI filename.
rem
rem This one file is shared among all of the pipeline utilities comprising
rem SrTask.bat.  The single INI file has [sections] for each utility.
rem
rem NOTE: Referring to a batch argument with percent tilda like %~1 
rem       instead of %1 strips off any quotes.  The quotes can be added 
rem       later where they are needed.
rem       
rem       

set INIFILE=%~1
if "%INIFILE%" == "" (
        set INIFILE=..\SrTask.ini
)



rem Check the INI syntax:
rem
rem Before actually executing it is best to check the INI syntax.  If there is
rem a syntax error, this batch file terminates.  Fix the error and try again.
rem 
rem Note:
rem
rem These syntax checks are done without the /to clause on the utilities.  
rem Because of that the "nextprog" field on the INI reports will be reported 
rem as NULL.  See below for the /to clause on each when the utilities are
rem actually run.
rem 
rem 

echo.
echo.
echo.
echo SRTASK.BAT: Checking INI syntax:
echo.

Blast /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Pak2Bin /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Bin2Asc /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError

goto :SyntaxGood

:SyntaxError
    echo. 
    echo SRTASK.BAT: ERROR, failed INI syntax check, quitting ...
    echo.
    goto :Return

:SyntaxGood
    echo.
    echo SRTASK.BAT: SUCCESS, INI syntax checks passed ...
    echo.




rem Start the pipeline chain in the background.
rem
rem NOTES:
rem
rem * A single INI file is shared between all three utilities
rem * Sampling rates, etc ... are all set in the INI file SrTask.ini
rem * The INI filename is specified once in the env variable INIFILE
rem
rem * "Start /b" is the Windows way of starting a process in the background
rem
rem
rem

echo.
echo.
echo SRTASK.BAT: Starting the pipeline in the background ...

start /b    Blast.exe  "%INIFILE%"  /to Pak2Bin
start /b  Pak2Bin.exe  "%INIFILE%"  /to Bin2Asc
start /b  Bin2Asc.exe  "%INIFILE%"  /to NULL

echo SRTASK.BAT: background pipeline started ... see *.rpt files for info
echo.



rem Return.
rem
rem

:Return

echo.
echo.
echo SRTASK.BAT: Done
echo.
echo ***** WARNING: Do NOT kill this window or acquisition will STOP ! ***
echo ***** WARNING: Do NOT kill this window or acquisition will STOP ! ***
echo.

