@echo off

rem FILE: AcquireFast.bat  ( Acquiring 10kHz Data )
rem COPYRIGHT: (c), Symmetric Research, 2016
rem
rem This example sets up a pipeline to acquire data at a fast 10kHz sampling
rem rate and save it to disk in binary PAK files.  All processing is postponed
rem until a later time and is controlled by the ProcessFast.bat file.
rem


rem Save path to the current example directory.

set EXAMPLEDIR=%CD%


rem Keep all title and path changes local ( ie restore on exit )

setlocal

title SR ACQUIREFAST.BAT - ( Blast Saving PAK Files )
path C:\SR\USBXCH\Exe;%PATH%



rem Announce the program start:
rem
rem

echo ACQUIREFAST.BAT: Starting ...
echo.



rem Create a YMDHMS data directory:
rem
rem YMDHMS = ( year, month, day, hour, minute, second).
rem
rem The SR YmdHms.exe utility creates a blank YMDHMS directory for storing data
rem from the current acquisition run.  An actual directory name will be something
rem like "2014-05-29-at-15-47-46" reflecting the current date and time.
rem
rem YmdHms.exe also writes the batch file YmdHmsSetEnv.bat for setting an
rem environment variable with the specific YMDHMS that can be referred to in the
rem rest of this batch file.
rem
rem All processing utilities are run in the YMDHMS directory so any output
rem files are saved there.
rem
rem

echo.
echo ACQUIREFAST.BAT: Creating the YMDHMS data directory for this run:

YmdHms  > nul
call YmdHmsSetEnv.bat

echo.
echo    success ... created: %SR_YMDHMS%
cd %SR_YMDHMS%




rem Check for USBxCH driver and board presence.
rem
rem

echo.
echo ACQUIREFAST.BAT: Checking for USBxCH presence ( SrUsbXch0 ):
echo.

Presence.exe SrUsbXch0

if ERRORLEVEL 1 goto :Return



rem Set an environment variable with the INI filename.
rem
rem This one file is shared among all of the pipeline utilities comprising
rem ACQUIREFAST.BAT.  The single INI file has [sections] for each utility.
rem
rem

set INIFILE=%EXAMPLEDIR%\AcquireFast.ini



rem Check the INI syntax:
rem
rem Before actually executing it is best to check the INI syntax.  If there is
rem a syntax error, this batch file terminates.  Fix the error and try again.
rem 
rem Note:
rem
rem These syntax checks are done without /to clause on the utilities.  Because
rem of that the "nextprog" field on the INI reports will be reported as NULL.  See
rem below for the /to clause on each when the utilities are actually run.
rem 
rem 

echo.
echo.
echo.
echo ACQUIREFAST.BAT: Checking INI syntax:
echo.

Blast /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.


goto :SyntaxGood

:SyntaxError
    echo. 
    echo ACQUIREFAST.BAT: ERROR, failed INI syntax check, quitting ...
    echo.
    goto :Return

:SyntaxGood
    echo.
    echo ACQUIREFAST.BAT: SUCCESS, INI syntax checks passed ...
    echo.




rem Start the pipeline chain in the background.
rem
rem NOTES:
rem
rem * A single INI file is shared between all three utilities
rem * Sampling rates, etc ... are all set in the INI file Ascii.ini
rem * The INI filename is specified once in the env variable INIFILE
rem
rem * "Start /b" is the Windows way of starting a process in the background
rem * AsciiDisplay.exe runs in the foreground, no /b on its "start"
rem
rem
rem

echo.
echo.
echo ACQUIREFAST.BAT: Starting the pipeline in the background ...

start /b  Blast.exe  "%INIFILE%"  /to NULL

echo ACQUIREFAST.BAT: background pipeline started ... see *.rpt files for info
echo.



rem Return, advising the user what will happen.
rem
rem

:Return

echo.
echo.
echo ACQUIREFAST.BAT: Return NOTE
echo.
echo If AcquireFast.bat was started by double clicking from Windows File Explorer,
echo this window will go away after "press any key to continue" ...
echo.
echo If AcquireFast.bat was started from a command prompt, it will return to the
echo command prompt.  Run tasklist etc to see processes running ...
echo.
pause
echo.

