@echo off

rem FILE: ProcessFast.bat  ( Processing 10kHz Data )
rem COPYRIGHT: (c), Symmetric Research, 2014-2016
rem
rem This example sets up a pipeline to process previously acquired data
rem saved to disk as binary PAK files.  The PAK files are read in, converted 
rem to BIN format, and output in ASCII format.  The companion batch file, 
rem AcquireFast.bat, can be used to acquire the data.
rem
rem


rem Save path to the current example directory.

set EXAMPLEDIR=%CD%


rem Keep all title and path changes local ( ie restore on exit )

setlocal

title SR PROCESSFAST.BAT - ( Process PAK files to ASC )
path C:\SR\USBXCH\Exe;%PATH%



rem Announce the program start:
rem
rem

echo PROCESSFAST.BAT: Starting ...
echo.



rem Change to the most recently created YMDHMS data directory:
rem
rem YMDHMS = ( year, month, day, hour, minute, second ).
rem
rem This assumes AcquireFast.bat has been run.  If so, both a batch file 
rem named YmdHmsSetEnv.bat and a corresponding YMDHMS directory should 
rem exist.  The actual directory name will be something like
rem "2014-05-29-at-15-47-46" reflecting the current date and time.
rem
rem Running the batch file sets the SR_YMDHMS environment variable which
rem can be used to change into the matching YMDHMS data directory.  All
rem processing utilities are run in this YMDHMS directory so any output
rem files are saved there.
rem
rem To change to a directory other than the most recent, comment in the set
rem line and comment out the call line below.  Then edit the set line for the
rem desired directory.
rem
rem

echo.
echo PROCESSFAST.BAT: Change to the YMDHMS data directory from the recent run:

rem Remove the comment on the line below to use the specified directory OR ...
rem set SR_YMDHMS=SampleData

rem Remove the comment on the line below to use the directory from the most 
rem recent run.
call YmdHmsSetEnv.bat

cd %SR_YMDHMS%

echo.
echo    changed directory to: %SR_YMDHMS%



rem Set an environment variable with the INI filename.
rem
rem This one file is shared among all of the pipeline utilities comprising
rem PROCESSFAST.BAT.  The single INI file has [sections] for each utility.
rem
rem

set INIFILE=%EXAMPLEDIR%\ProcessFast.ini




rem Check the INI syntax:
rem
rem Before actually executing it is best to check the INI syntax.  If there is
rem a syntax error, this batch file terminates.  Fix the error and try again.
rem 
rem Note:
rem
rem These syntax checks are done without /to clause on the utilities.  Because
rem of that the "nextprog" field on the INI reports will be reported as NULL.  See
rem below for the /to clause on each when the utilities are actually run.
rem 
rem 

echo.
echo.
echo.
echo PROCESSFAST.BAT: Checking INI syntax:
echo.

PakFread /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Pak2Bin /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Bin2Asc /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError


goto :SyntaxGood

:SyntaxError
    echo. 
    echo PROCESSFAST.BAT: ERROR, failed INI syntax check, quitting ...
    echo.
    goto :Return

:SyntaxGood
    echo.
    echo PROCESSFAST.BAT: SUCCESS, INI syntax checks passed ...
    echo.




rem Start the pipeline chain in the background.
rem
rem NOTES:
rem
rem * A single INI file is shared between all three utilities
rem * Sampling rates, etc ... are all set in the INI file ProcessFast.ini
rem * The INI filename is specified once in the env variable INIFILE
rem * "Start /b" is the Windows way of starting a process in the background
rem
rem

echo.
echo.
echo PROCESSFAST.BAT: Starting the pipeline in the background ...

start /b        PakFread.exe  "%INIFILE%"  /to Pak2Bin
start /b         Pak2Bin.exe  "%INIFILE%"  /to Bin2Asc
start /b         Bin2Asc.exe  "%INIFILE%"  /to NULL

echo PROCESSFAST.BAT: background pipeline started ... see *.rpt files for info
echo.



rem Return, advising the user what will happen.
rem
rem

:Return

echo.
echo.
echo PROCESSFAST.BAT: Return NOTE
echo.
echo If ProcessFast.bat was started by double clicking from Windows File Explorer,
echo this window will go away after "press any key to continue" ...
echo.
echo If ProcessFast.bat was started from a command prompt, it will return to the
echo command prompt.  Run tasklist etc to see processes running ...
echo.
pause
echo.

