@echo off

rem FILE: ScopeMultiple.bat  ( Scope on multiple USBxCH )
rem COPYRIGHT: (c), Symmetric Research, 2016
rem
rem This example sets up a pipeline to run the Scope program on two
rem USBxCH at the same time.
rem
rem



rem Save path to the current example directory.

set EXAMPLEDIR=%CD%


rem Keep all title and path changes local ( ie restore on exit )

setlocal

title SR SCOPEMULTIPLE.BAT - ( Scope on multiple USBxCH )
path C:\SR\USBXCH\Exe;%PATH%



rem Announce the program start:

echo SCOPEMULTIPLE.BAT: Starting ...
echo.



rem Make duplicate copies of the needed executables, but add
rem different prefixes so they can all run simultaneously without
rem pipe names colliding.
rem
rem

set EXEDIR=C:\SR\USBXCH\Exe

copy /y %EXEDIR%\Blast.exe %EXEDIR%\Sr0Blast.exe
copy /y %EXEDIR%\Blast.exe %EXEDIR%\Sr1Blast.exe

copy /y %EXEDIR%\Pak2Bin.exe %EXEDIR%\Sr0Pak2Bin.exe
copy /y %EXEDIR%\Pak2Bin.exe %EXEDIR%\Sr1Pak2Bin.exe

copy /y %EXEDIR%\Interp.exe %EXEDIR%\Sr0Interp.exe
copy /y %EXEDIR%\Interp.exe %EXEDIR%\Sr1Interp.exe

copy /y %EXEDIR%\Bin2Asc.exe %EXEDIR%\Sr0Bin2Asc.exe
copy /y %EXEDIR%\Bin2Asc.exe %EXEDIR%\Sr1Bin2Asc.exe

copy /y %EXEDIR%\ScopeDisplay.exe %EXEDIR%\Sr0ScopeDisplay.exe
copy /y %EXEDIR%\ScopeDisplay.exe %EXEDIR%\Sr1ScopeDisplay.exe

copy /y %EXEDIR%\ScopeDisplayBackend.exe %EXEDIR%\Sr0ScopeDisplayBackend.exe
copy /y %EXEDIR%\ScopeDisplayBackend.exe %EXEDIR%\Sr1ScopeDisplayBackend.exe



rem Set environment variables with the INI file names.
rem Two INI files are used.  One for each USBxCH system.
rem
rem       
rem       

set INIFILE0=%EXAMPLEDIR%\Scope0.ini
set INIFILE1=%EXAMPLEDIR%\Scope1.ini




rem Create a YMDHMS data directory:
rem
rem YMDHMS = ( year, month, day, hour, minute, second).
rem
rem The SR YmdHms.exe utility creates a blank YMDHMS directory for storing data
rem from the current acquisition run.  An actual directory name will be something
rem like "2014-05-29-at-15-47-46" reflecting the current date and time.
rem
rem YmdHms.exe also writes the batch file YmdHmsSetEnv.bat for setting an
rem environment variable with the specific YMDHMS that can be referred to in the
rem rest of this batch file.
rem
rem All processing utilities are run in the YMDHMS directory so any output
rem files are saved there.
rem
rem

echo.
echo SCOPEMULTIPLE.BAT: Creating the YMDHMS data directory for this run:

YmdHms  > nul
call YmdHmsSetEnv.bat

echo.
echo    success ... created: %SR_YMDHMS%
cd %SR_YMDHMS%




rem Create two directories, one for each USBxCH system.
rem This is necessary to keep the report files separated.
rem
rem

mkdir Scope0
mkdir Scope1

echo.
echo    created Scope0 and Scope1 directories
echo.



rem Change to directory #0, check USBxCH presence and ini syntax.
rem
rem

cd Scope0



rem Check USBxCH board and driver presence.
rem 
rem 

echo.
echo SCOPEMULTIPLE.BAT: Checking for USBxCH presence ( SrUsbXch0 ):
echo.

Presence.exe SrUsbXch0

if ERRORLEVEL 1  goto :Return


rem Check the INI syntax:
rem
rem Before actually executing it is best to check the INI syntax.  If there is
rem a syntax error, this batch file terminates.  Fix the error and try again.
rem 
rem Note:
rem
rem These syntax checks are done without the /to clause on the utilities.  Because
rem of that the "nextprog" field on the INI reports will be reported as NULL.  See
rem below for the /to clause on each when the utilities are actually run.
rem 
rem 

echo.
echo.
echo.
echo SCOPEMULTIPLE.BAT: Checking INI #0 syntax:
echo.

Sr0Blast /syntax "%INIFILE0%"
if ERRORLEVEL 1 goto :SyntaxError0
echo.

Sr0Pak2Bin /syntax "%INIFILE0%"
if ERRORLEVEL 1 goto :SyntaxError0
echo.

Sr0Interp /syntax "%INIFILE0%"
if ERRORLEVEL 1 goto :SyntaxError0
echo.

Sr0Bin2Asc /syntax "%INIFILE0%"
if ERRORLEVEL 1 goto :SyntaxError0
echo.

Sr0ScopeDisplay /syntax "%INIFILE0%"
if ERRORLEVEL 1 goto :SyntaxError0
echo.

goto :SyntaxGood0


:SyntaxError0
echo. 
echo SCOPEMULTIPLE.BAT: ERROR, failed INI #0 syntax check, quitting ...
echo. 
goto :Return

:SyntaxGood0
echo.
echo SCOPEMULTIPLE.BAT: SUCCESS, INI #0 syntax check passed ...
echo.





rem Change to directory #1, check USBxCH presence and ini syntax
rem
rem

cd ..\Scope1


echo.
echo SCOPEMULTIPLE.BAT: Checking for USBxCH presence ( SrUsbXch1 ):
echo.

Presence.exe SrUsbXch1

if ERRORLEVEL 1  goto :Return


echo.
echo.
echo.
echo SCOPEMULTIPLE.BAT: Checking INI #1 syntax:
echo.

Sr1Blast /syntax "%INIFILE1%"
if ERRORLEVEL 1 goto :SyntaxError1
echo.

Sr1Pak2Bin /syntax "%INIFILE1%"
if ERRORLEVEL 1 goto :SyntaxError1
echo.

Sr1Interp /syntax "%INIFILE1%"
if ERRORLEVEL 1 goto :SyntaxError1
echo.

Sr1Bin2Asc /syntax "%INIFILE1%"
if ERRORLEVEL 1 goto :SyntaxError1
echo.

Sr1ScopeDisplay /syntax "%INIFILE1%"
if ERRORLEVEL 1 goto :SyntaxError1
echo.

goto :SyntaxGood1


:SyntaxError1
echo. 
echo SCOPEMULTIPLE.BAT: ERROR, failed INI #1 syntax check, quitting ...
echo. 
goto :Return

:SyntaxGood1
echo.
echo SCOPEMULTIPLE.BAT: SUCCESS, INI #1 syntax check passed ...
echo.





rem Change to directory #0 and start pipeline chain in the background.
rem
rem NOTES:
rem
rem * Sampling rates, etc ... are all set in the single INI file #0
rem * "Start /b" is the Windows way of starting a process in the background
rem
rem

cd ..\Scope0

echo.
echo.
echo SCOPEMULTIPLE.BAT: Starting pipeline #0 in the background ...

start /b        Sr0Blast.exe  "%INIFILE0%"  /to Sr0Pak2Bin
start /b      Sr0Pak2Bin.exe  "%INIFILE0%"  /to Sr0Interp
start /b       Sr0Interp.exe  "%INIFILE0%"  /to Sr0Bin2Asc
start /b      Sr0Bin2Asc.exe  "%INIFILE0%"  /to Sr0ScopeDisplay
start /b Sr0ScopeDisplay.exe  "%INIFILE0%"  /to NULL

echo SCOPEMULTIPLE.BAT: background pipeline #0 started ... see *.rpt files for info
echo.



rem Change to directory #1 and start pipeline chain in the background
rem
rem

cd ..\Scope1

echo.
echo.
echo SCOPEMULTIPLE.BAT: Starting pipeline #1 in the background ...

start /b        Sr1Blast.exe  "%INIFILE1%"  /to Sr1Pak2Bin
start /b      Sr1Pak2Bin.exe  "%INIFILE1%"  /to Sr1Interp
start /b       Sr1Interp.exe  "%INIFILE1%"  /to Sr1Bin2Asc
start /b      Sr1Bin2Asc.exe  "%INIFILE1%"  /to Sr1ScopeDisplay
start /b Sr1ScopeDisplay.exe  "%INIFILE1%"  /to NULL

echo SCOPEMULTIPLE.BAT: background pipeline #1 started ... see *.rpt files for info
echo.





rem Return, telling the user what will happen.
rem
rem

:Return

echo.
echo.
echo SCOPEMULTIPLE.BAT: Return NOTE
echo.
echo If ScopeMultiple.bat was started by double clicking from Windows File Explorer,
echo this window will go away after "press any key to continue" ...
echo.
echo If ScopeMultiple.bat was started from a command prompt, it will return to the
echo command prompt.  Run tasklist etc to see processes running ...
echo.

rem Wait to clean up copied executables.
rem
rem

echo *****************************************************************
echo *** The next step will delete the copied executables.         ***
echo *** Do NOT press enter until both ScopeDisplays are finished. ***
echo *****************************************************************
echo. 
pause

pushd %EXEDIR%
del /Q Sr0*
del /Q Sr1*
popd

echo.
