// FILE: Abs.c
// COPYRIGHT: (c), Symmetric Research, 2016-2017
//
// Source code for the Abs.exe custom USBxCH BIN pipeline utility in C.
//
// Open the input and output pipes, then processes USBxCH BIN records as they
// arrive, taking the abs() of the analog values and saving the modified values
// in the BIN records passed down the pipeline.
//
// The file CustomPipeLib.c must also be compiled and linked in to provide the
// pipeline functions used here.
//
//


// Include files:

#include <stdio.h>
#include <stdlib.h>
#include <math.h>               // for abs

#include "CustomPipeLib.h"      // for prototypes, BIN, and other SR defines


// Main program:

int main( int argc, char *argv[] ) {

        char         *NextProg;
        char         InputPipeName[MAXSTR];
        char         OutputPipeName[MAXSTR];
        SRPIPEHANDLE hInputPipe;
        SRPIPEHANDLE hOutputPipe;
        BIN          Pt;
        int          i;


        // Open the report file and announce the program.

        CustomReportOpen( "Abs" );
        CustomReportPrint( "Abs starting\n" );



        // Process the command line for the "next program" name.

        if ( argc == 2 )

                NextProg = argv[1];

        else {
                // it is a bad command line, quit ...

                CustomReportPrint( "Usage: Abs NextProg\n" );
                exit( 0 );
                }


        // Form the input and output pipe names.

        sprintf( InputPipeName,  "%s%s", REQUIRED_PIPE_PREFIX, "Abs" );
        sprintf( OutputPipeName, "%s%s", REQUIRED_PIPE_PREFIX, NextProg );

    

        // Open the input and output pipes.

        hInputPipe  = CustomOpenInputPipe( InputPipeName );
        hOutputPipe = CustomOpenOutputPipe( OutputPipeName );

          // >> careful programmers might add error checking to confirm the
          // >> input and output pipes were successfully opened ...



        // Loop reading from the input pipe.

        while ( CustomReadInputPipe( hInputPipe, &Pt ) ) {

                // Ok ... a sample point BIN record has been returned by
                //     CustomReadInputPipe() at &Pt ...
                //
                // ... compute abs() on all the analog channels ...
                // 

                for ( i = 0 ; i < MAXANALOGCHANNELS ; i++ )
                        Pt.Analog[i] = abs( Pt.Analog[i] );
                

                // And pass the modified BIN record on to output pipe ...

                CustomWriteOutputPipe( hOutputPipe, &Pt );

                }


        // The input pipe has failed ( upstream is probably closing down ),
        // close all gracefully ...

        CustomCloseInputPipe(  hInputPipe );
        CustomCloseOutputPipe( hOutputPipe );

        exit( 0 );

}

