@echo off

rem FILE: "Run Filt3.bat"
rem Setup and run the "Last.c" example pipeline.
rem
rem

rem Set local environment variables, window title, and executable search path.
rem
rem   ... include the standard UsbXch executable directory
rem   ... include the current directory for the Last.exe program
rem

set BATCHFILE=200 Run Last.bat
set INIFILE=201 Run Last.ini

title SR "%BATCHFILE%" starting

path C:\SR\USBXCH\Exe;%CD%;%PATH%



rem Announce the program start:

echo.
echo Running "%BATCHFILE%"
echo.


rem Check the INI syntax:
rem
rem Before executing check the INI syntax for each SR utility.
rem
rem   ... if there is an INI error fix it and try again ...
rem 
rem NOTE: >>>
rem
rem These syntax checks are done without /to clause on the utilities.  Because
rem of that the "nextprog" field on the INI reports will be reported as NULL.  See
rem below for the /to clause on each when the utilities are actually run.
rem 
rem 

set SR_RPT="SrRpt-All.rpt"

echo.
echo *** CHECKING INI syntax in "%INIFILE%":
echo.

echo Blast
Blast /syntax "%INIFILE%"               > %SR_RPT%
if ERRORLEVEL 1 ( goto :SyntaxError )

echo Pak2bin
Pak2Bin /syntax "%INIFILE%"             >> %SR_RPT%
if ERRORLEVEL 1 ( goto :SyntaxError )

echo Bin2Asc
Bin2Asc /syntax "%INIFILE%"              >> %SR_RPT%
if ERRORLEVEL 1 ( goto :SyntaxError )

echo ScopeDisplay
ScopeDisplay /syntax "%INIFILE%"         >> %SR_RPT%
if ERRORLEVEL 1 ( goto :SyntaxError )

rem ... No ini sytax to check for "Filt3.exe" ...

goto :SyntaxGood

:SyntaxError
        echo.
        echo     ... ERROR: bad ini syntax, see the respective *.rpt file for details
        echo.
        pause
        goto :EOF

:SyntaxGood
        echo.
        echo Success, all INI syntax checks passed ...
        del *.rpt
        echo.




rem Check for USBxCH driver and board presence.

echo.
echo *** CHECKING for USBxCH driver and board presence ( SrUsbXch0 ):

Presence.exe SrUsbXch0
if ERRORLEVEL 1 (
        pause
        goto :EOF
        )

del *.rpt




rem Create a YMDHMS data directory:
rem
rem YMDHMS = ( year, month, day, hour, minute, second).
rem
rem The SR YmdHms.exe utility creates a blank YMDHMS directory for storing data
rem from the current acquisition run.  An actual directory name will be something
rem like "2014-05-29-at-15-47-46" reflecting the current date and time.
rem
rem YmdHms.exe also writes the batch file YmdHmsSetEnv.bat for setting an
rem environment variable with the specific YMDHMS that can be referred to in the
rem rest of this batch file.
rem
rem All processing utilities are run in the YMDHMS directory so any output
rem files are saved there.
rem
rem

echo.
echo *** CREATING the YMDHMS data directory for this run:

YmdHms  > nul
call YmdHmsSetEnv.bat

echo.
echo    success ... created: %SR_YMDHMS%
pushd %SR_YMDHMS%



rem Start the pipeline chain in the background.
rem
rem NOTES:
rem
rem    * A single INI file is shared between all three utilities
rem    * Sampling rates, etc ... are all set in the INI file
rem    * For Windows, "start /b" starts a process in the background
rem

echo.
echo *** STARTING the pipeline in the .\%SR_YMDHMS% directory:

start /b         Blast.exe  "..\%INIFILE%"  /to Pak2Bin
start /b       Pak2Bin.exe  "..\%INIFILE%"  /to Filt3
start /b         Filt3.exe                      Bin2Asc
start /b       Bin2Asc.exe  "..\%INIFILE%"  /to ScopeDisplay
start /b  ScopeDisplay.exe  "..\%INIFILE%"  /to NULL

echo.
echo *** The pipeline is now running in the background ...
echo.



rem Return, telling the user what will happen.
rem
rem

:Return

rem Return from YMDHMS directory to original directory. 
popd

echo.
echo.
echo *** Return NOTE
echo.
echo If this batch file was started by double clicking from Windows File Explorer,
echo this window will go away after "press any key to continue" ...
echo.
echo If this batch file was started from a command prompt, it will return to the
echo command prompt.  Run tasklist etc to see processes running ...
echo.
pause
echo.

