@echo off

rem FILE: "Run Last.bat"
rem COPYRIGHT: (c), Symmetric Research, 2014-2019
rem
rem Setup and run the "Last.c" example pipeline.
rem
rem

rem Set local environment variables, window title, and executable search path.
rem
rem   ... include the standard UsbXch executable directory
rem   ... include the current directory for the Last.exe program
rem

set BATCHFILE=200 Run Last.bat
set INIFILE=201 Run Last.ini

title SR "%BATCHFILE%" starting

path C:\SR\USBXCH\Exe;%CD%;%PATH%



rem Announce the program start:

echo.
echo Running "%BATCHFILE%"
echo.


rem Check the INI syntax:
rem
rem Before executing check the INI syntax for each SR utility.
rem
rem   ... if there is an INI error fix it and try again ...
rem 
rem NOTE: >>>
rem
rem These syntax checks are done without /to clause on the utilities.  Because
rem of that the "nextprog" field on the INI reports will be reported as NULL.  See
rem below for the /to clause on each when the utilities are actually run.
rem 
rem 

set SR_RPT="SrRpt-All.rpt"

echo.
echo *** CHECKING INI syntax in "%INIFILE%":
echo.

echo Blast
Blast /syntax "%INIFILE%"               > %SR_RPT%
if ERRORLEVEL 1 ( goto :SyntaxError )

echo Pak2bin
Pak2Bin /syntax "%INIFILE%"             >> %SR_RPT%
if ERRORLEVEL 1 ( goto :SyntaxError )

echo Interp
Interp /syntax "%INIFILE%"              >> %SR_RPT%
if ERRORLEVEL 1 ( goto :SyntaxError )

rem ... No ini sytax to check for "Last.exe" ...

goto :SyntaxGood

:SyntaxError
        echo.
        echo     ... ERROR: bad ini syntax, see the respective *.rpt file for details
        echo.
        pause
        goto :EOF

:SyntaxGood
        echo.
        echo Success, all INI syntax checks passed ...
        del *.rpt
        echo.




rem Check for USBxCH driver and board presence.

echo.
echo *** CHECKING for USBxCH driver and board presence ( SrUsbXch0 ):

Presence.exe SrUsbXch0
if ERRORLEVEL 1 (
        pause
        goto :EOF
        )

del *.rpt



rem Start the pipeline chain in the background.
rem
rem NOTES:
rem
rem    * A single INI file is shared between all three utilities
rem    * Sampling rates, etc ... are all set in the INI file
rem    * For Windows, "start /b" starts a process in the background
rem

if not EXIST Data ( mkdir Data )
cd Data

echo.
echo *** STARTING the pipeline in the .\Data directory:
echo.

start /b     Blast.exe  "..\%INIFILE%"  /to Pak2Bin
start /b   Pak2Bin.exe  "..\%INIFILE%"  /to Interp
start /b    Interp.exe  "..\%INIFILE%"  /to Last
start /b      Last.exe

echo.
echo.
echo *** The pipeline is now running in the background ...
echo.
echo   to kill the pipeline do one of the following:
echo.
echo     1) click on the 'X' in the upper right corner of the comand line window
echo     2) from the keyboard use "Alt+spacebar C" to kill the command line window
echo     3) from a separate command line window run "Kill Last.bat"
echo     4) use TaskManager to kill the pipeline processes by hand
echo.
echo.

