@echo off

rem FILE: "Run Custom.bat"
rem COPYRIGHT: (c), Symmetric Research, 2016-2018
rem
rem This batch file sets up a USBxCH pipeline which runs the VbAbs.exe custom
rem Visual Basic utility on acquired data.
rem 
rem Documentation for the standard pipeline utilities used here can be found in
rem the "Docs" directory.  Executables are in the "Exe" directory.
rem
rem For an introduction to pipeline processing, see the "App - Ascii" and other
rem "App - ..." directories.
rem
rem


rem Set the window title:

title SR CUSTOM.BAT - ( Custom Absolute value in Visual Basic, VbAbs.exe )



rem Set the Windows path environment variable:
rem
rem This batch file must be able to find the \SR\USBXCH\Exe utilities, and also
rem the custom Abs.exe utility.  Set the path to point to both.
rem

set VBABS_DIR=C:\SR\USBXCH\Examples\300 Writing a Custom Pipeline Utility in Visual Basic - Abs value
path C:\SR\USBXCH\Exe;%VBABS_DIR%



rem Echo the program is starting:

echo CUSTOM.BAT: Starting ...
echo.




rem Create a YMDHMS data directory:
rem
rem YMDHMS = ( year, month, day, hour, minute, second).
rem
rem The SR YmdHms.exe utility creates a blank YMDHMS directory for storing data
rem from the current acquisition run.  An actual directory name will be something
rem like "2014-05-29-at-15-47-46" reflecting the current date and time.
rem
rem YmdHms.exe also writes the batch file YmdHmsSetEnv.bat for setting an
rem environment variable with the specific YMDHMS that can be referred to in the
rem rest of this batch file.
rem
rem All processing utilities are run in the YMDHMS directory so any output
rem files are saved there.
rem
rem

echo.
echo CUSTOM.BAT: Creating the YMDHMS data directory for this run:

YmdHms  > nul
call YmdHmsSetEnv.bat

echo.
echo    success ... created: %SR_YMDHMS%
pushd %SR_YMDHMS%




rem Check for USBxCH driver and board presence.

echo.
echo CUSTOM.BAT: Checking for USBxCH presence ( SrUsbXch0 ):
echo.

Presence.exe SrUsbXch0

if ERRORLEVEL 1  goto :Return




rem Set an environment variable with the INI file name.

set INIFILE=%VBABS_DIR%\101 Run Custom.ini



rem Check the INI syntax:
rem
rem Before actually executing it is best to check the INI syntax.  If there is
rem a syntax error, this batch file terminates.  Fix the error and try again.
rem 
rem Note:
rem
rem These syntax checks are done without /to clause on the utilities.  Because
rem of that the "nextprog" field on the INI reports will be reported as NULL.  See
rem below for the /to clause on each when the utilities are actually run.
rem 
rem 

echo.
echo.
echo.
echo CUSTOM.BAT: Checking INI syntax:
echo.

Blast /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Pak2Bin /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Interp /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

Bin2Asc /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

DvmDisplay /syntax "%INIFILE%"
if ERRORLEVEL 1 goto :SyntaxError
echo.

goto :SyntaxGood


:SyntaxError
echo. 
echo CUSTOM.BAT: ERROR, failed INI syntax check, quitting ...
echo. 
goto :Return

:SyntaxGood
echo.
echo CUSTOM.BAT: SUCCESS, INI syntax check passed ...
echo.




rem Start the pipeline chain in the background.
rem
rem NOTES:
rem
rem * Sampling rates, etc ... are all set in the single INI file
rem * "Start /b" is the Windows way of starting a process in the background
rem
rem

echo.
echo.
echo CUSTOM.BAT: Starting the pipeline in the background ...

start /b       Blast.exe  "%INIFILE%"  /to Pak2Bin
start /b     Pak2Bin.exe  "%INIFILE%"  /to Interp
start /b      Interp.exe  "%INIFILE%"  /to VbAbs
start /b       VbAbs.exe                   Bin2Asc
start /b     Bin2Asc.exe  "%INIFILE%"  /to DvmDisplay
start /b  DvmDisplay.exe  "%INIFILE%"  /to NULL

echo CUSTOM.BAT: background pipeline started ... see *.rpt files for info
echo.



rem Return, telling the user what will happen.
rem
rem

:Return

rem Return from YMDHMS directory to original directory. 
popd

echo.
echo.
echo CUSTOM.BAT: Return NOTE
echo.
echo If Custom.bat was started by double clicking from Windows File Explorer,
echo this window will go away after "press any key to continue" ...
echo.
echo If Custom.bat was started from a command prompt, it will return to the
echo command prompt.  Run tasklist etc to see processes running ...
echo.
pause
echo.

