@echo off

rem FILE: StepHost1Analyze.bat
rem COPYRIGHT: (c), Symmetric Research, 2011-2013
rem
rem Process multiple USB thumb drive YMDHMS directories over to the PC
rem hard drive.  Copy, unpack bz2 files, and convert to ASCII.
rem
rem Set the SR_X environment variables below for the directories and
rem programs to use.  Modify them as appropriate for your system.
rem
rem The 7-zip freeware program from www.7-zip.org is used for unpacking.
rem The SR Pak2Bin and Bin2Asc utilities are used for the final ASCII conversion.
rem
rem This batch file is for Windows command line usage.  It is assumed this
rem batch file will be run on a desktop class machine.  As the amounts of
rem data grow into the GBytes runtime will become long.
rem
rem Runtime errors and log messages are saved to a report file.  See
rem this file for errors when done ...
rem
rem
rem Some of the Windows command line syntax used below is:
rem
rem     for /D   -> process directories only
rem     ( ... )  -> groups several commands with a single for statement
rem     echo.    -> display a blank line
rem     %%~nd    -> get just the filename part of a full path, etc
rem
rem
rem For more info on batch file syntax see the Windows help system.
rem Search on keywords like command-line and "batch file".
rem
rem



rem Initialize environment variables:
rem
rem NOTE: ** MODIFY THESE TO POINT TO THE APPROPRIATE PLACES ***
rem
rem
set SR_THUMBDRIVE="E:"
set SR_DATAPATH="C:\Data\Station001"

set SR_UNZIPCMD=%SR_DATAPATH%\7za.exe
set SR_UNZIPARGS=e -tbzip2 -y 
set SR_PAK2BIN=\SR\USBXCH\Utilities\Pak2Bin\Pak2Bin file
set SR_BIN2ASC=\SR\USBXCH\Utilities\Bin2Asc\Bin2Asc SrPipePak2Bin fw4

set SR_RPT=%SR_DATAPATH%\StepHost1Analyze.rpt




rem  Announce StepHost1Analyze.bat file is running:
rem
rem
cls
echo FILE: StepHost1Analyze.bat
echo DESC: copy USB thumb YMDHMS data to PC hard drive and unpack
echo.




rem Save the User's current working directory:
rem
rem   Will return to this directory on exit ...
rem
set SR_USER_DIRECTORY=%CD%




rem Report the USB thumb drive source and hard disk destination:
rem
rem
echo.
echo Parameter summary ...
echo.
echo   SR_THUMBDRIVE = %SR_THUMBDRIVE%
echo     SR_DATAPATH = %SR_DATAPATH%
echo.




rem Check the USB thumb, SR Data directory, and unzip program are available:
rem
rem
if not exist %SR_THUMBDRIVE% (

        echo.
        echo ERROR: Cannot find source USB thumb %SR_THUMBDRIVE%
        echo.
        echo    Please plug in usb thumb or fix SR_THUMBDRIVE variable

        goto ErrorExit3

)

if not exist %SR_DATAPATH% (

        echo.
        echo ERROR: Cannot find the PC destination directory
        echo.
        echo    Please create the destination by hand or fix SR_DATAPATH variable

        goto ErrorExit3

)

if not exist %SR_UNZIPCMD% (

        echo.
        echo ERROR: Cannot find the unzip program %SR_UNZIPCMD%
        echo.
        echo    Please copy the unzip program by hand or fix SR_UNZIPCMD variable

        goto ErrorExit3

)




rem Copy all USB thumb data directories to the PC hard disk:
rem
rem   Don't carry the TS .bz directory extensions forward to the PC ...
rem
rem
echo.
echo.
echo Copy SR_THUMBDRIVE YMDHMS data directories to SR_DATAPATH ...
echo Copy SR_THUMBDRIVE YMDHMS data directories to SR_DATAPATH ...  >> %SR_RPT%
echo.

for /D %%d in ( %SR_THUMBDRIVE%\20??-* ) do (

        if exist %SR_DATAPATH%\%%~nd (

                echo.
                echo     ERROR: SR_DATAPATH\%%~nd already exists !

                goto ErrorExit17

        ) else (

                echo     %%~nd[.bz]  copying to SR_DATAPATH

                xcopy /i %%d %SR_DATAPATH%\%%~nd  >> %SR_RPT%

                )

        )




rem Unpack all YMDHMS .bz2 to .pak:
rem
rem
echo.
echo.
echo Unpack any SR_DATAPATH .bz2 to .pak with 7za ...
echo Unpack any SR_DATAPATH .bz2 to .pak with 7za ...  >> %SR_RPT%
echo.

for /D %%d in (%SR_DATAPATH%\20??-*) do (

        cd %%d

        if exist *.pak.bz2 (

                echo     %%~nd\*.pak.bz2  unpacking to *.pak
                echo     %%~nd\*.pak.bz2  unpacking to *.pak  >> %SR_RPT%

                %SR_UNZIPCMD% %SR_UNZIPARGS% *.pak.bz2  >> %SR_RPT%
                del *.pak.bz2  >> %SR_RPT%

        ) else (

                echo     %%~nd\*.pak.bz2  *** no bz2 files to unzip !
                echo     %%~nd\*.pak.bz2  *** no bz2 files to unzip ! >> %SR_RPT%

                ) 

        )



rem Convert all YMDHMS .pak to ASCII:
rem
rem
echo.
echo.
echo Convert all SR_DATAPATH .pak to ASCII with Pak2Bin ...
echo Convert all SR_DATAPATH .pak to ASCII with Pak2Bin ...  >> %SR_RPT%
echo.

for /D %%d in (%SR_DATAPATH%\20??-*) do (

        cd %%d

        if exist Pak2Bin-*.* (

                echo     %%~nd\*.pak  *** already converted to ASCII !
                echo     %%~nd\*.pak  *** already converted to ASCII !  >> %SR_RPT%

        ) else (

                echo     %%~nd\*.pak  converting to ASCII
                echo     %%~nd\*.pak  converting to ASCII  >> %SR_RPT%

                %SR_PAK2BIN% 00000000.pak  >> %SR_RPT%
                %SR_BIN2ASC%               >> %SR_RPT%

                )

        )



rem Return to the user:
rem
rem

:NormalReturn
        echo.
        echo.
        echo ** FINISHED **
        echo ** FINISHED **
        echo.
        echo.
        echo Please see the report file for any errors:
        echo.
        echo     SR_DATAPATH\StepHost1Analyze.rpt
        echo.
        set SR_RETURN_LEVEL=0
        goto Return


:ErrorExit3
        echo     Exiting StepHost1Analyze.bat with errorlevel 3
        echo.
        set SR_RETURN_LEVEL=3
        goto Return


:ErrorExit17
        echo     Exiting StepHost1Analyze.bat with errorlevel 17
        echo.
        set SR_RETURN_LEVEL=17
        goto Return


:Return
        cd %SR_USER_DIRECTORY%
        pause
        exit /b %SR_RETURN_LEVEL%
