// FILE: WaitUntilReady.c (WINDOWS VERSION)
// COPYRIGHT: (c), Symmetric Research, 2010-2016
//
// WaitUntilReady is a helper program that can be easily called from a
// batch file such as SleepWake.bat.  It waits for the READY_EVENT to be
// signaled and then exits.
//

#include <windows.h>
#include <powrprof.h>  // for suspend and wake functions

#include <stdio.h>
#include <stdlib.h>
#include <errno.h>

#define READY_EVENT "ReadyEvent"

int WaitForEvent( char *EventName );


int main( void ) {

        if ( WaitForEvent( READY_EVENT ) )
                exit( 0 );
        else {
                printf( "WaitUntilReady failed wait for event call.\n" );
                exit( 1 );
                }
}

int WaitForEvent( char *EventName ) {

        HANDLE EventHandle;
        int    Result;


        // Open or create event.

        EventHandle = CreateEvent( 
                                  NULL,     // LPSECURITY_ATTRIBUTES lpEventAttributes,
                                  TRUE,     // BOOL bManualReset,
                                  FALSE,    // BOOL bInitialState, starts reset
                                  EventName // LPCTSTR lpName
                                 );
        if ( EventHandle == NULL )
                return( 0 );

        
        // Wait for the event to be signaled and clear it with ResetEvent.
        // First time is just for flushing pipeline, second time is for real.

        Result = WaitForSingleObject( EventHandle, INFINITE ) == WAIT_OBJECT_0;

        if ( Result ) {
                ResetEvent( EventHandle );

                Result = WaitForSingleObject( EventHandle, INFINITE ) == WAIT_OBJECT_0;

                if ( Result )
                        ResetEvent( EventHandle );
                }
        
        CloseHandle( EventHandle );

        return( Result );
}
